"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getRaffleAccountDataSerializer = void 0;
const serializers_1 = require("@metaplex-foundation/umi/serializers");
const generated_1 = require("../generated");
const raffleAccountData_1 = require("../generated/types/raffleAccountData");
const constant_1 = require("../constant");
const getRaffleAccountDataSerializer = () => ({
    description: 'RaffleAccountData',
    fixedSize: null,
    maxSize: null,
    serialize: () => {
        throw new Error('Operation not supported.');
    },
    deserialize: (buffer, offset = 0) => {
        // Raffle.
        const [raffle, raffleOffset] = (0, raffleAccountData_1.getRaffleAccountDataSerializer)().deserialize(buffer, offset);
        if (raffle.key !== generated_1.AccountKey.Raffle) {
            throw new Error(`Expected a Raffle account, got account data key: ${raffle.key}`);
        }
        // Winners.
        let winners = [];
        let finalOffset = raffleOffset;
        if (raffle.allocator.size > 0) {
            [winners, finalOffset] = (0, serializers_1.array)((0, generated_1.getNodeSerializer)(), {
                size: raffle.allocator.size,
            }).deserialize(buffer, raffleOffset + constant_1.ENTRY_SPACE);
        }
        // Tickets.
        let tickets = [];
        if (raffle.issued > 0) {
            [tickets, finalOffset] = (0, serializers_1.array)((0, serializers_1.publicKey)(), {
                size: 'remainder',
            }).deserialize(buffer, raffleOffset + constant_1.ENTRY_SPACE * (raffle.allocator.capacity + 1));
        }
        return [
            {
                ...raffle,
                winners,
                tickets,
            },
            finalOffset,
        ];
    },
});
exports.getRaffleAccountDataSerializer = getRaffleAccountDataSerializer;
//# sourceMappingURL=raffleAccountData.js.map